@@ -24,6 +24,7 @@ from decimal import Decimal
 from enum import Enum
 from typing import List, Optional, Tuple, Union
 from urllib.parse import ParseResult, urlparse
+from uuid import uuid4
 
 from . import OrganizationalContact, OrganizationalEntity, Tool, XsUri
 from .impact_analysis import ImpactAnalysisAffectedStatus, ImpactAnalysisJustification, ImpactAnalysisResponse, \
@@ -644,7 +645,7 @@ class Vulnerability:
                  # Deprecated Parameters kept for backwards compatibility
                  source_name: Optional[str] = None, source_url: Optional[str] = None,
                  recommendations: Optional[List[str]] = None) -> None:
-        self.bom_ref = bom_ref
+        self.bom_ref = bom_ref or str(uuid4())
         self.id = id
         self.source = source
         self.references = references or []
@@ -677,8 +678,10 @@ class Vulnerability:
         """
         Get the unique reference for this Vulnerability in this BOM.
 
+        If a value was not provided in the constructor, a UUIDv4 will have been assigned.
+
         Returns:
-           `str` if set else `None`
+           `str` unique identifier for this Vulnerability
         """
         return self._bom_ref
 
